/**
 * Hook to create a React Portal.
 * Automatically handles creating and tearing-down the root elements (no SRR
 * makes this trivial), so there is no need to ensure the parent target already exists.
 * @example
 * const target = usePortal(id, [id]);
 * return createPortal(children, target);
 * @param {String} id The id of the target container, e.g 'portal-root'
 * @returns {HTMLDivElement} The DOM node to use as the Portal target.
 */
declare const usePortal: (id: string) => HTMLDivElement;
export default usePortal;
